package db

import (
	"context"
	"go.mongodb.org/mongo-driver/bson"
	"go.mongodb.org/mongo-driver/mongo"
	"go.mongodb.org/mongo-driver/mongo/options"
	"time"
	"valera/config"
)

type chatDTO struct {
	ChatID int64 `bson:"chat_id"`
}

type chatInfoDTO struct {
	ChatID   int64     `bson:"chat_id"`
	Workouts []Workout `bson:"workouts"`
}

type Workout struct {
	Name  string `bson:"name"`
	Count int    `bson:"count"`
}

func NewWorkout(
	name string,
	count int,
) *Workout {
	return &Workout{
		Name:  name,
		Count: count,
	}
}

var cfg *config.Config

func init() {
	cfg = config.NewConfig()
}

func AddChat(chatID int64) error {
	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	defer cancel()

	client, err := mongo.Connect(ctx, options.Client().ApplyURI(cfg.MongoURL))
	if err != nil {
		return err
	}

	collection := client.Database(cfg.DBName).Collection(cfg.ChatsCollectionName)

	result := collection.FindOne(ctx, bson.M{"chat_id": chatID})
	if result.Err() == mongo.ErrNoDocuments {
		if _, err := collection.InsertOne(ctx, &chatDTO{ChatID: chatID}); err != nil {
			return err
		}
		return nil
	}
	return result.Err()
}

func AddWorkoutInUser(chatID int64, workout *Workout) error {
	if err := AddChat(chatID); err != nil {
		return err
	}

	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	defer cancel()

	client, err := mongo.Connect(ctx, options.Client().ApplyURI(cfg.MongoURL))
	if err != nil {
		return err
	}

	collection := client.Database(cfg.DBName).Collection(cfg.ChatsCollectionName)
	_, err = collection.UpdateOne(
		ctx,
		bson.M{"chat_id": chatID},
		bson.M{"$push": bson.M{"workouts": workout}},
	)
	return err
}

func GetUsers(chatID int64) ([]string, error) {
	//	ctx, cancel := context.WithTimeout(context.Background(), time.Second)
	//	defer cancel()
	//
	//	client, err := mongo.Connect(ctx, options.Client().ApplyURI(cfg.MongoURL))
	//	if err != nil {
	//		return nil, err
	//	}
	//
	//	collection := client.Database(cfg.DBName).Collection(cfg.ChatsCollectionName)
	//	chatInfoDTO := &chatInfoDTO{}
	//	if err := collection.FindOne(ctx, bson.M{"chat_id": chatID}).Decode(chatInfoDTO); err != nil {
	//		return nil, err
	//	}
	//	return chatInfoDTO.Users, err
	return nil, nil
}
